@@ -108,7 +108,7 @@ QByteArray PersistentSearchAttribute::serialized() const
     l.append("QUERYSTRING");
     l.append(ImapParser::quote(d->queryString.toUtf8()));
     l.append("QUERYCOLLECTIONS");
-    l.append("(" + cols.join(QLatin1Char(' ')).toLatin1() + ')');
+    l.append("(" + cols.join(u' ').toLatin1() + ')');
     if (d->remote) {
         l.append("REMOTE");
     }
