@@ -21,7 +21,6 @@
 #include "handler/itemlinkhandler.h"
 #include "handler/itemmodifyhandler.h"
 #include "handler/itemmovehandler.h"
-#include "handler/itemsynchandler.h"
 #include "handler/loginhandler.h"
 #include "handler/logouthandler.h"
 #include "handler/resourceselecthandler.h"
@@ -129,12 +128,6 @@ std::unique_ptr<Handler> Handler::findHandlerForCommandAuthenticated(Protocol::C
         Q_ASSERT_X(cmd != Protocol::Command::StreamPayload, __FUNCTION__, "StreamPayload command is not allowed in this context");
         return {};
 
-    case Protocol::Command::BeginItemSync:
-        return std::make_unique<ItemSyncHandler>(akonadi);
-    case Protocol::Command::EndItemSync:
-        Q_ASSERT_X(cmd != Protocol::Command::EndItemSync, __FUNCTION__, "EndItemSync command is not allowed in this context");
-        return {};
-
     case Protocol::Command::ItemChangeNotification:
         Q_ASSERT_X(cmd != Protocol::Command::ItemChangeNotification, __FUNCTION__, "ItemChangeNotification command is not allowed on this connection");
         return {};
