@@ -20,8 +20,6 @@
 
 #include <algorithm>
 
-#include "private/tristate_p.h"
-
 using namespace Akonadi::Server;
 
 DbInitializer::Ptr DbInitializer::createInstance(const QSqlDatabase &database, Schema *schema)
@@ -79,12 +77,17 @@ bool DbInitializer::run()
 #ifndef DBINITIALIZER_UNITTEST
         // Now finally check and set the generation identifier if necessary
         auto store = DataStore::dataStoreForDatabase(mDatabase);
-        SchemaVersion version = SchemaVersion::retrieveAll(store).at(0);
-        if (version.generation() == 0) {
-            version.setGeneration(QDateTime::currentDateTimeUtc().toSecsSinceEpoch());
-            version.update(store);
+        const auto schemaVersions = SchemaVersion::retrieveAll(store);
+        if (schemaVersions.empty()) {
+            qCDebug(AKONADISERVER_LOG) << "DbInitializer: SchemaVersion not found; skipping generation update";
+        } else {
+            auto version = schemaVersions.at(0);
+            if (version.generation() == 0) {
+                version.setGeneration(QDateTime::currentSecsSinceEpoch());
+                version.update(store);
 
-            qCDebug(AKONADISERVER_LOG) << "Generation:" << version.generation();
+                qCDebug(AKONADISERVER_LOG) << "Generation:" << version.generation();
+            }
         }
 #endif
 
@@ -328,7 +331,7 @@ QString DbInitializer::buildCreateIndexStatement(const TableDescription &tableDe
     }
 
     return QStringLiteral("CREATE %1 INDEX %2 ON %3 (%4)")
-        .arg(indexDescription.isUnique ? QStringLiteral("UNIQUE") : QString(), indexName, tableDescription.name, columns.join(QLatin1Char(',')));
+        .arg(indexDescription.isUnique ? QStringLiteral("UNIQUE") : QString(), indexName, tableDescription.name, columns.join(u','));
 }
 
 QStringList DbInitializer::buildAddForeignKeyConstraintStatements(const TableDescription &table, const ColumnDescription &column) const
@@ -373,7 +376,7 @@ QString DbInitializer::buildPrimaryKeyStatement(const TableDescription &table)
             cols.push_back(column.name);
         }
     }
-    return QLatin1StringView("PRIMARY KEY (") + cols.join(QLatin1StringView(", ")) + QLatin1Char(')');
+    return QLatin1StringView("PRIMARY KEY (") + cols.join(QLatin1StringView(", ")) + u')';
 }
 
 void DbInitializer::execQuery(const QString &queryString)
