@@ -818,11 +818,11 @@ public:
             return;
         }
 
-        if (name.contains(QLatin1Char('/'))) {
+        if (name.contains(u'/')) {
             KMessageBox::error(parentWidget, i18n("We can not add \"/\" in folder name."), i18nc("@title:window", "Create New Folder Error"));
             return;
         }
-        if (name.startsWith(QLatin1Char('.')) || name.endsWith(QLatin1Char('.'))) {
+        if (name.startsWith(QLatin1Char('.')) || name.endsWith(u'.')) {
             KMessageBox::error(parentWidget, i18n("We can not add \".\" at begin or end of folder name."), i18nc("@title:window", "Create New Folder Error"));
             return;
         }
@@ -1065,7 +1065,8 @@ public:
                     i18n("Before syncing folder \"%1\" it is necessary to have the resource online. Do you want to make it online?", collection.displayName()),
                     i18n("Account \"%1\" is offline", instance.name()),
                     KGuiItem(i18nc("@action:button", "Go Online"), QIcon::fromTheme(QStringLiteral("user-online"))),
-                    KStandardGuiItem::cancel())
+                    KStandardGuiItem::cancel(),
+                    QStringLiteral("askGoOnline"))
                 != KMessageBox::ButtonCode::PrimaryAction) {
                 return false;
             }
@@ -1660,7 +1661,7 @@ public:
             }
 
             QString label = model->data(index).toString();
-            label.replace(QLatin1Char('&'), QStringLiteral("&&"));
+            label.replace(u'&', QStringLiteral("&&"));
 
             const auto icon = model->data(index, Qt::DecorationRole).value<QIcon>();
 
@@ -1944,7 +1945,7 @@ QAction *StandardActionManager::createAction(Type type)
     }
 
     if (type == ToggleWorkOffline) {
-        // inititalize the action state with information from config file
+        // initialize the action state with information from config file
         disconnect(action, SIGNAL(triggered(bool)), this, standardActionData[type].slot); // clazy:exclude=old-style-connect
         action->setChecked(workOffline());
         connect(action, SIGNAL(triggered(bool)), this, standardActionData[type].slot); // clazy:exclude=old-style-connect
